.. rst-class:: detail

Zone
===============

.. currentmodule:: compas_rrc

.. autoclass:: Zone

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~Zone.__init__
    
    